@@ -21,7 +21,7 @@ our ( $VERSION, $COMPATIBLE, $FILENAME );
 
 
 # $VERSION is also in Parse/Eyapp.pm
-$VERSION = "1.170";
+$VERSION = "1.171";
 $COMPATIBLE = '0.07';
 $FILENAME   =__FILE__;
 
@@ -1044,17 +1044,16 @@ sub YYCurval {
 }
 
 {
-  sub YYSymbolicSim {
+  sub YYSimStack {
     my $self = shift;
     my $stack = shift;
     my @reduce = @_;
     my @expected;
 
-    while (@reduce) {
-      my $index = shift @reduce;
+    for my $index (@reduce) {
       my ($lhs, $length) = @{$self->{RULES}[-$index]};
-      my @auxstack = @$stack;
-      if (@auxstack > $length) {
+      if (@$stack > $length) {
+        my @auxstack = @$stack;
         splice @auxstack, -$length if $length;
 
         my $state = $auxstack[-1]->[0];
@@ -1093,84 +1092,25 @@ sub YYCurval {
     $reduce{$state->{DEFAULT}} = 1 if exists($state->{DEFAULT});
 
     if (keys %reduce) {
-      %expected = (%expected, $self->YYSymbolicSim($stack, keys %reduce));
+      %expected = (%expected, $self->YYSimStack($stack, keys %reduce));
     }
     
     return keys %expected;
   }
 
   sub YYExpect {
-    return YYExpected(@_, [ @{$_[0]->{STACK}} ]);
+    my $self = shift;
+    $self->YYExpected($self->{STACK}, @_);
   }
 }
 
-#{
-#  my @STACK; # Used for symbolic simulation !!! reentrancy problem??
-#
-#  sub YYSymbolicSim {
-#    my $self = shift;
-#    my @reduce = @_;
-#    my @expected;
-#
-#    while (@reduce) {
-#      my $index = shift @reduce;
-#      my ($lhs, $length) = @{$self->{RULES}[-$index]};
-#      if (@STACK > $length) {
-#        splice @STACK, -$length if $length;
-#
-#        my $state = $STACK[-1]->[0];
-#        my $nextstate = $self->{STATES}[$state]{GOTOS}{$lhs};
-#        if (defined($nextstate)) {
-#          push @STACK, [$nextstate, undef];
-#          @expected = $self->YYExpected;
-#        }
-#      }
-#      # else something went wrong!!! See Frank Leray report
-#    }
-#
-#    return map { $_ => 1 } @expected;
-#  }
-#
-#  sub YYExpected {
-#    my($self)=shift;
-#
-#    # The state in the top of the stack
-#    my $state = $self->{STATES}[$STACK[-1][0]];
-#
-#    my %actions;
-#    %actions = %{$state->{ACTIONS}} if exists $state->{ACTIONS};
-#
-#    # The keys of %reduction are the -production numbers
-#    # Use hashes and not lists to guarantee that no tokens are repeated
-#    my (%expected, %reduce); 
-#    for (keys(%actions)) {
-#      if ($actions{$_} > 0) { # shift
-#        $expected{$_} = 1;
-#        next;
-#      }
-#      $reduce{$actions{$_}} = 1;
-#    }
-#    $reduce{$state->{DEFAULT}} = 1 if exists($state->{DEFAULT});
-#
-#    if (keys %reduce) {
-#      %expected = (%expected, $self->YYSymbolicSim(keys %reduce));
-#    }
-#    
-#    return keys %expected;
-#  }
-#
-#  sub YYExpect {
-#    @STACK = @{$_[0]->{STACK}};
-#    goto &YYExpected;
-#  }
-#}
-
 # $self->expects($token) : returns true if the token is among the expected ones
 sub expects {
   my $self = shift;
   my $token = shift;
 
-  return grep { $_ eq $token } $self->YYExpect;
+  my @expected = $self->YYExpect;
+  return grep { $_ eq $token } @expected;
 }
 
 BEGIN {
